@@ -8,6 +8,7 @@ describe 'basic manila' do
       pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
+      include openstack_integration::apache
       include openstack_integration::rabbitmq
       include openstack_integration::mysql
       include openstack_integration::keystone
@@ -57,6 +58,7 @@ describe 'basic manila' do
         ssl => false,
       }
       class { 'manila::scheduler': }
+      class { 'manila::cron::db_purge': }
 
       # missing: backends, share, service_instance
       EOS
@@ -71,5 +73,8 @@ describe 'basic manila' do
       it { is_expected.to be_listening }
     end
 
+    describe cron do
+      it { is_expected.to have_entry('1 0 * * * manila-manage db purge 0 >>/var/log/manila/manila-rowsflush.log 2>&1').with_user('manila') }
+    end
   end
 end
