@@ -28,17 +28,15 @@ describe 'manila::share::hitachi_hnas' do
     end
   end
 
-
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
-      }).each do |os,facts|
-        context "on #{os}" do
-          let (:facts) do
-            facts.merge(OSDefaults.get_facts({ :osfamily => "#{os}" }))
-          end
-
-          it_configures 'hitachi hnas share driver'
-        end
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts())
       end
 
+      it_configures 'hitachi hnas share driver'
+    end
+  end
 end
