@@ -8,17 +8,17 @@ describe 'manila::backend::cephfs' do
       {
         :driver_handles_share_servers       => false,
         :share_backend_name                 => 'cephfs',
+        :backend_availability_zone          => 'my_zone',
         :cephfs_conf_path                   => '$state_path/ceph.conf',
         :cephfs_auth_id                     => 'manila',
         :cephfs_cluster_name                => 'ceph',
-        :cephfs_enable_snapshots            => true,
         :cephfs_protocol_helper_type        => 'NFS',
         :cephfs_ganesha_server_ip           => '10.0.0.1',
         :cephfs_ganesha_export_ips          => '10.0.0.1,1001::1001',
         :cephfs_ganesha_server_is_remote    => true,
         :cephfs_ganesha_server_username     => 'ganeshadmin',
         :cephfs_ganesha_path_to_private_key => '/readable/by/manila.key',
-        :cephfs_volume_mode                 => '0775'
+        :cephfs_volume_mode                 => '0775',
       }
     end
 
@@ -27,14 +27,14 @@ describe 'manila::backend::cephfs' do
         'manila.share.drivers.cephfs.driver.CephFSDriver')
       is_expected.to contain_manila_config('cephfs/share_backend_name').with_value(
         'cephfs')
+      is_expected.to contain_manila_config('cephfs/backend_availability_zone').with_value(
+        'my_zone')
       is_expected.to contain_manila_config('cephfs/cephfs_conf_path').with_value(
         '$state_path/ceph.conf')
       is_expected.to contain_manila_config('cephfs/cephfs_auth_id').with_value(
         'manila')
       is_expected.to contain_manila_config('cephfs/cephfs_cluster_name').with_value(
         'ceph')
-      is_expected.to contain_manila_config('cephfs/cephfs_enable_snapshots').with_value(
-        true)
       is_expected.to contain_manila_config('cephfs/cephfs_protocol_helper_type').with_value(
         'NFS')
       is_expected.to contain_manila_config('cephfs/cephfs_ganesha_server_ip').with_value(
