@@ -4,21 +4,21 @@ describe 'manila::backend::dellemc_isilon' do
 
   let(:title) {'dellemc_isilon'}
 
-  let :params do
+  let :required_params do
     {
-      :driver_handles_share_servers         => false,
-      :emc_nas_login                        => 'admin',
-      :emc_nas_password                     => 'password',
-      :emc_nas_server                       => '127.0.0.2',
-      :emc_share_backend                    => 'isilon',
-      :emc_nas_root_dir                     => '',
+      :emc_nas_login     => 'admin',
+      :emc_nas_password  => 'password',
+      :emc_nas_server    => '127.0.0.2',
+      :emc_share_backend => 'isilon',
     }
   end
 
   let :default_params do
     {
-      :emc_nas_server_port           => 8080,
-      :emc_nas_server_secure         => true,
+      :backend_availability_zone => '<SERVICE DEFAULT>',
+      :emc_nas_root_dir          => '<SERVICE DEFAULT>',
+      :emc_nas_server_port       => 8080,
+      :emc_nas_server_secure     => true,
     }
   end
 
@@ -30,6 +30,7 @@ describe 'manila::backend::dellemc_isilon' do
     it 'configures dell emc isilon share driver' do
       is_expected.to contain_manila_config("dellemc_isilon/share_driver").with_value(
         'manila.share.drivers.dell_emc.driver.EMCShareDriver')
+      is_expected.to contain_manila_config("dellemc_isilon/driver_handles_share_servers").with_value(false)
       params_hash.each_pair do |config,value|
         is_expected.to contain_manila_config("dellemc_isilon/#{config}").with_value( value )
       end
@@ -42,25 +43,24 @@ describe 'manila::backend::dellemc_isilon' do
 
   shared_examples 'manila::backend::dellemc_isilon' do
     context 'with default parameters' do
-      before do
-        params = {}
+      let :params do
+        required_params
       end
 
       it_configures 'dell emc isilon share driver'
     end
 
     context 'with provided parameters' do
-      it_configures 'dell emc isilon share driver'
-    end
-
-    context 'with share server config' do
-     before do
-       params.merge!({
-          :emc_nas_password => true,
+      let :params do
+        required_params.merge!({
+          :emc_nas_root_dir          => 'myroot',
+          :emc_nas_server_port       => 8000,
+          :emc_nas_server_secure     => false,
+          :backend_availability_zone => 'my_zone',
         })
       end
 
-      it { is_expected.to raise_error(Puppet::Error) }
+      it_configures 'dell emc isilon share driver'
     end
   end
 
