@@ -7,6 +7,7 @@ describe 'manila::backend::netapp' do
   let :params do
     {
       :driver_handles_share_servers        => true,
+      :backend_availability_zone           => 'my_zone',
       :netapp_login                        => 'netapp',
       :netapp_password                     => 'password',
       :netapp_server_hostname              => '127.0.0.2',
@@ -19,13 +20,14 @@ describe 'manila::backend::netapp' do
 
   let :default_params do
     {
+      :backend_availability_zone            => '<SERVICE DEFAULT>',
       :netapp_transport_type                => 'http',
       :netapp_storage_family                => 'ontap_cluster',
       :netapp_volume_name_template          => 'share_%(share_id)s',
       :netapp_vserver_name_template         => 'os_%s',
       :netapp_lif_name_template             => 'os_%(net_allocation_id)s',
       :netapp_aggregate_name_search_pattern => '(.*)',
-      :netapp_root_volume_name              => 'root',
+      :netapp_root_volume                   => '<SERVICE DEFAULT>',
       :netapp_port_name_search_pattern      => '(.*)',
     }
   end
