@@ -30,12 +30,12 @@ describe 'Puppet::Type.type(:manila_config)' do
 
   it 'should accept a valid value' do
     @manila_config[:value] = 'bar'
-    expect(@manila_config[:value]).to eq('bar')
+    expect(@manila_config[:value]).to eq(['bar'])
   end
 
   it 'should not accept a value with whitespace' do
     @manila_config[:value] = 'b ar'
-    expect(@manila_config[:value]).to eq('b ar')
+    expect(@manila_config[:value]).to eq(['b ar'])
   end
 
   it 'should accept valid ensure values' do
